using System.ComponentModel.DataAnnotations;
using System.Net;
using System.Net.Mail;

namespace NSeguin.Dev.Web;

public class SmtpSettings
{
    [Required]
    public string? Host { get; set; } = null!;

    [Required]
    public int Port { get; set; }

    [Required]
    public string? Username { get; set; } = null!;

    [Required]
    public string? Password { get; set; } = null!;

    public bool EnableSsl { get; set; } = true;

    public int TimeoutMs { get; set; } = 10000;

    public TimeSpan Timeout
    {
        get => TimeSpan.FromMilliseconds(TimeoutMs);
        set => TimeoutMs = (int)value.TotalMilliseconds;
    }

    public SmtpClient CreateSmtpClient()
    {
        SmtpClient smtpClient = new(Host, Port)
        {
            UseDefaultCredentials = false,
            Credentials = CreateNetworkCredential(),
            EnableSsl = EnableSsl,
            Timeout = TimeoutMs,
            DeliveryMethod = SmtpDeliveryMethod.Network,
        };

        return smtpClient;
    }

    public NetworkCredential CreateNetworkCredential()
    {
        return new NetworkCredential(Username, Password);
    }
}
